@@ -11,7 +11,7 @@ Benchmark.bmbm do |x|
     Prawn::Document.new do
       N.times do
         (1..5).each do |i|
-          draw_text 'Hello Prawn', at: [200, i * 100]
+          draw_text('Hello Prawn', at: [200, i * 100])
         end
         start_new_page
       end
