@@ -9,10 +9,10 @@ N = 2000
 Benchmark.bmbm do |x|
   x.report('TTF text') do
     Prawn::Document.new do
-      font "#{Prawn::DATADIR}/fonts/DejaVuSans.ttf"
+      font("#{Prawn::DATADIR}/fonts/DejaVuSans.ttf")
       N.times do
         (1..5).each do |i|
-          draw_text 'Hello Prawn', at: [200, i * 100]
+          draw_text('Hello Prawn', at: [200, i * 100])
         end
         start_new_page
       end
