@@ -1,36 +1,21 @@
 # frozen_string_literal: true
 
-# transformation.rb: Implements rotate, translate, skew, scale and a generic
-#                     transformation_matrix
-#
-# Copyright January 2010, Michael Witrant. All Rights Reserved.
-#
-# This is free software. Please see the LICENSE and COPYING files for details.
-
 module Prawn
   module Graphics
+    # Implements user-space coordinate transformation.
     module Transformation
       # @group Stable API
 
-      # Rotate the user space.  If a block is not provided, then you must save
+      # Rotate the user space. If a block is not provided, then you must save
       # and restore the graphics state yourself.
       #
-      # == Options
-      # <tt>:origin</tt>:: <tt>[number, number]</tt>. The point around which to
-      #                    rotate. A block must be provided if using the :origin
-      #
-      # raises <tt>Prawn::Errors::BlockRequired</tt> if an :origin option is
-      # provided, but no block is given
-      #
-      # Example without a block:
-      #
+      # @example
       #   save_graphics_state
       #   rotate 30
       #   text "rotated text"
       #   restore_graphics_state
       #
-      # Example with a block: rotating a rectangle around its upper-left corner
-      #
+      # @example Rotating a rectangle around its upper-left corner
       #   x = 300
       #   y = 300
       #   width = 150
@@ -40,6 +25,14 @@ module Prawn
       #     pdf.stroke_rectangle([x, y], width, height)
       #   end
       #
+      # @param angle [Number] Angle in degrees.
+      # @param options [Hash{Symbol => any}]
+      # @option options :origin [Array(Number, Number)] Rotation origin point.
+      #   A block must be provided if specified.
+      # @yield
+      # @raise [Prawn::Errors::BlockRequired] if an `:origin` option is
+      #   provided, but no block is given.
+      # @return [void]
       def rotate(angle, options = {}, &block)
         Prawn.verify_options(:origin, options)
         rad = degree_to_rad(angle)
@@ -52,27 +45,24 @@ module Prawn
 
           x = options[:origin][0] + bounds.absolute_left
           y = options[:origin][1] + bounds.absolute_bottom
-          x_prime = x * cos - y * sin
-          y_prime = x * sin + y * cos
+          x_prime = (x * cos) - (y * sin)
+          y_prime = (x * sin) + (y * cos)
           translate(x - x_prime, y - y_prime) do
             transformation_matrix(cos, sin, -sin, cos, 0, 0, &block)
           end
         end
       end
 
-      # Translate the user space.  If a block is not provided, then you must
+      # Translate the user space. If a block is not provided, then you must
       # save and restore the graphics state yourself.
       #
-      # Example without a block: move the text up and over 10
-      #
+      # @example Move the text up and over 10
       #   save_graphics_state
       #   translate(10, 10)
       #   text "scaled text"
       #   restore_graphics_state
       #
-      # Example with a block: draw a rectangle with its upper-left corner at
-      #                       x + 10, y + 10
-      #
+      # @example draw a rectangle with its upper-left corner at x + 10, y + 10
       #   x = 300
       #   y = 300
       #   width = 150
@@ -81,29 +71,24 @@ module Prawn
       #     pdf.stroke_rectangle([x, y], width, height)
       #   end
       #
+      # @param x [Number]
+      # @param y [Number]
+      # @yield
+      # @return [void]
       def translate(x, y, &block)
         transformation_matrix(1, 0, 0, 1, x, y, &block)
       end
 
-      # Scale the user space.  If a block is not provided, then you must save
+      # Scale the user space. If a block is not provided, then you must save
       # and restore the graphics state yourself.
       #
-      # == Options
-      # <tt>:origin</tt>:: <tt>[number, number]</tt>. The point from which to
-      #                    scale. A block must be provided if using the :origin
-      #
-      # raises <tt>Prawn::Errors::BlockRequired</tt> if an :origin option is
-      # provided, but no block is given
-      #
-      # Example without a block:
-      #
+      # @example
       #   save_graphics_state
       #   scale 1.5
       #   text "scaled text"
       #   restore_graphics_state
       #
-      # Example with a block: scale a rectangle from its upper-left corner
-      #
+      # @example Scale a rectangle from its upper-left corner
       #   x = 300
       #   y = 300
       #   width = 150
@@ -113,6 +98,14 @@ module Prawn
       #     pdf.stroke_rectangle([x, y], width, height)
       #   end
       #
+      # @param factor [Number] Scale factor.
+      # @param options [Hash{Symbol => any}]
+      # @option options :origin [Array(Number, Number)] The point from which to
+      #   scale. A block must be provided if specified.
+      # @yield
+      # @raise [Prawn::Errors::BlockRequired] If an `:origin` option is
+      #   provided, but no block is given.
+      # @return [void]
       def scale(factor, options = {}, &block)
         Prawn.verify_options(:origin, options)
         if options[:origin].nil?
@@ -142,8 +135,22 @@ module Prawn
       # end
 
       # Transform the user space (see notes for rotate regarding graphics state)
-      # Generally, one would use the rotate, scale, translate, and skew
+      # Generally, one would use the {rotate}, {scale}, and {translate}
       # convenience methods instead of calling transformation_matrix directly
+      #
+      # @param matrix [Array(Number, Number, Number, Number, Number, Number)]
+      #   Transformation matrix.
+      #
+      #   The six elements correspond to the following elements of the
+      #   transformation matrix:
+      #
+      #   ```plain
+      #   a b 0
+      #   c d 0
+      #   e f 0
+      #   ```
+      # @yield
+      # @return [void]
       def transformation_matrix(*matrix)
         if matrix.length != 6
           raise ArgumentError,
@@ -154,7 +161,7 @@ module Prawn
         add_to_transformation_stack(*matrix)
 
         values = PDF::Core.real_params(matrix)
-        renderer.add_content "#{values} cm"
+        renderer.add_content("#{values} cm")
         if block_given?
           yield
           restore_graphics_state
