@@ -1,28 +1,26 @@
 # frozen_string_literal: true
 
-# image.rb : Base class for image info objects
-#
-# Copyright September 2011, Brad Ediger. All rights reserved.
-#
-# This is free software. Please see the LICENSE and COPYING files for details.
-
 require 'digest/sha1'
 
 module Prawn
   module Images
+    # Base class for image info objects
+    # @abstract
     class Image
       # @group Extension API
 
+      # Calculate the final image dimensions from provided options.
+      # @private
       def calc_image_dimensions(options)
         w = options[:width] || width
         h = options[:height] || height
 
         if options[:width] && !options[:height]
-          wp = w / width.to_f
+          wp = w / Float(width)
           w = width * wp
           h = height * wp
         elsif options[:height] && !options[:width]
-          hp = h / height.to_f
+          hp = h / Float(height)
           w = width * hp
           h = height * hp
         elsif options[:scale]
@@ -30,8 +28,8 @@ module Prawn
           h = height * options[:scale]
         elsif options[:fit]
           bw, bh = options[:fit]
-          bp = bw / bh.to_f
-          ip = width / height.to_f
+          bp = bw / Float(bh)
+          ip = width / Float(height)
           if ip > bp
             w = bw
             h = bw / ip
