@@ -47,13 +47,13 @@ describe Prawn::Document do
                 local: nil,
                 font: nil,
                 size: nil,
-                character_spacing: nil
-              }
+                character_spacing: nil,
+              },
             ]
           end
         end
-      pdf = described_class.new text_formatter: text_formatter
-      pdf.text 'Dr. Who?', inline_format: true
+      pdf = described_class.new(text_formatter: text_formatter)
+      pdf.text('Dr. Who?', inline_format: true)
       text = PDF::Inspector::Text.analyze(pdf.render)
       expect(text.strings.first).to eq("Just 'The Doctor'.")
     end
@@ -64,7 +64,7 @@ describe Prawn::Document do
       custom_document = Class.new(described_class)
       custom_document.generate(Tempfile.new('generate_test').path) do |e|
         expect(e.class).to eq(custom_document)
-        expect(e).to be_a_kind_of(described_class)
+        expect(e).to be_a(described_class)
       end
     end
 
@@ -81,14 +81,14 @@ describe Prawn::Document do
       described_class.extensions.delete(mod1)
       described_class.extensions.delete(mod2)
 
-      expect(described_class.new.respond_to?(:test_extensions1)).to eq false
-      expect(described_class.new.respond_to?(:test_extensions2)).to eq false
+      expect(described_class.new.respond_to?(:test_extensions1)).to be false
+      expect(described_class.new.respond_to?(:test_extensions2)).to be false
 
       # verify these still exist on custom class
       expect(custom_document.extensions).to eq([mod1, mod2])
 
-      expect(custom_document.new.respond_to?(:test_extensions1)).to eq true
-      expect(custom_document.new.respond_to?(:test_extensions2)).to eq true
+      expect(custom_document.new.respond_to?(:test_extensions1)).to be true
+      expect(custom_document.new.respond_to?(:test_extensions2)).to be true
     end
   end
 
@@ -122,7 +122,7 @@ describe Prawn::Document do
       end
 
       it 'places a background image interntally if it is in options block' do
-        expect(pdf.instance_variable_defined?(:@background)).to eq(true)
+        expect(pdf.instance_variable_defined?(:@background)).to be(true)
         expect(pdf.instance_variable_get(:@background)).to eq(filename)
       end
     end
@@ -131,17 +131,17 @@ describe Prawn::Document do
   describe '#float' do
     it 'restores the original y-position' do
       orig_y = pdf.y
-      pdf.float { pdf.text 'Foo' }
+      pdf.float { pdf.text('Foo') }
       expect(pdf.y).to eq(orig_y)
     end
 
     it 'teleports across pages if necessary' do
       pdf.float do
-        pdf.text 'Foo'
+        pdf.text('Foo')
         pdf.start_new_page
-        pdf.text 'Bar'
+        pdf.text('Bar')
       end
-      pdf.text 'Baz'
+      pdf.text('Baz')
 
       pages = PDF::Inspector::Page.analyze(pdf.render).pages
       expect(pages.size).to eq(2)
@@ -152,9 +152,9 @@ describe Prawn::Document do
 
   describe '#start_new_page' do
     it "doesn't modify the options hash" do
-      expect do
+      expect {
         described_class.new.start_new_page({ margin: 0 }.freeze)
-      end.to_not raise_error
+      }.to_not raise_error
     end
 
     it 'sets individual page margins' do
@@ -166,11 +166,11 @@ describe Prawn::Document do
 
   describe '#delete_page(index)' do
     before do
-      pdf.text 'Page one'
+      pdf.text('Page one')
       pdf.start_new_page
-      pdf.text 'Page two'
+      pdf.text('Page two')
       pdf.start_new_page
-      pdf.text 'Page three'
+      pdf.text('Page three')
     end
 
     it 'destroy a specific page of the document' do
@@ -220,14 +220,14 @@ describe Prawn::Document do
     it 'is changed by go_to_page' do
       pdf = described_class.new
       10.times { pdf.start_new_page }
-      pdf.go_to_page 3
+      pdf.go_to_page(3)
       expect(pdf.page_number).to eq(3)
     end
   end
 
   describe 'on_page_create callback' do
     it 'is delegated from Document to renderer' do
-      expect(pdf.respond_to?(:on_page_create)).to eq true
+      expect(pdf.respond_to?(:on_page_create)).to be true
     end
 
     it 'is invoked with document' do
@@ -241,40 +241,40 @@ describe Prawn::Document do
     end
 
     it 'is invoked for each new page' do
-      trigger = instance_double('trigger')
-      allow(trigger).to receive(:fire)
+      trigger = instance_spy(Proc, 'trigger')
+      allow(trigger).to receive(:call)
 
-      pdf.renderer.on_page_create { trigger.fire }
+      pdf.renderer.on_page_create { trigger.call }
 
       5.times { pdf.start_new_page }
 
-      expect(trigger).to have_received(:fire).exactly(5).times
+      expect(trigger).to have_received(:call).exactly(5).times
     end
 
     it 'is replaceable' do
-      trigger1 = instance_double('trigger 1')
-      allow(trigger1).to receive(:fire)
+      trigger1 = instance_spy(Proc, 'trigger 1')
+      allow(trigger1).to receive(:call)
 
-      trigger2 = instance_double('trigger 2')
-      allow(trigger2).to receive(:fire)
+      trigger2 = instance_spy(Proc, 'trigger 2')
+      allow(trigger2).to receive(:call)
 
-      pdf.renderer.on_page_create { trigger1.fire }
+      pdf.renderer.on_page_create { trigger1.call }
 
       pdf.start_new_page
 
-      pdf.renderer.on_page_create { trigger2.fire }
+      pdf.renderer.on_page_create { trigger2.call }
 
       pdf.start_new_page
 
-      expect(trigger1).to have_received(:fire).once
-      expect(trigger2).to have_received(:fire).once
+      expect(trigger1).to have_received(:call).once
+      expect(trigger2).to have_received(:call).once
     end
 
     it 'is clearable by calling on_page_create without a block' do
-      trigger = instance_double('trigger')
-      allow(trigger).to receive(:fire)
+      trigger = instance_spy(Proc, 'trigger')
+      allow(trigger).to receive(:call)
 
-      pdf.renderer.on_page_create { trigger.fire }
+      pdf.renderer.on_page_create { trigger.call }
 
       pdf.start_new_page
 
@@ -282,7 +282,7 @@ describe Prawn::Document do
 
       pdf.start_new_page
 
-      expect(trigger).to have_received(:fire).once
+      expect(trigger).to have_received(:call).once
     end
   end
 
@@ -291,7 +291,7 @@ describe Prawn::Document do
       pdf = described_class.new(compress: false)
       allow(pdf.page.content.stream).to receive(:compress!).and_return(true)
 
-      pdf.text 'Hi There' * 20
+      pdf.text('Hi There' * 20)
       pdf.render
 
       expect(pdf.page.content.stream).to_not have_received(:compress!)
@@ -301,7 +301,7 @@ describe Prawn::Document do
       pdf = described_class.new(compress: true)
       allow(pdf.page.content.stream).to receive(:compress!).and_return(true)
 
-      pdf.text 'Hi There' * 20
+      pdf.text('Hi There' * 20)
       pdf.render
 
       expect(pdf.page.content.stream).to have_received(:compress!).once
@@ -311,8 +311,8 @@ describe Prawn::Document do
       doc_uncompressed = described_class.new
       doc_compressed = described_class.new(compress: true)
       [doc_compressed, doc_uncompressed].each do |pdf|
-        pdf.font "#{Prawn::DATADIR}/fonts/gkai00mp.ttf"
-        pdf.text '更可怕的是，同质化竞争对手可以按照URL中后面这个ID来遍历' * 10
+        pdf.font("#{Prawn::DATADIR}/fonts/gkai00mp.ttf")
+        pdf.text('更可怕的是，同质化竞争对手可以按照URL中后面这个ID来遍历' * 10)
       end
 
       expect(doc_compressed.render.length).to be <
@@ -325,7 +325,7 @@ describe Prawn::Document do
       pdf = described_class.new(info: { Author: 'Lóránt' })
       expect(pdf.state.store.info.object).to match(
         # UTF-16:     BOM L   ó   r   á   n   t
-        %r{/Author\s*<feff004c00f3007200e1006e0074>}i
+        %r{/Author\s*<feff004c00f3007200e1006e0074>}i,
       )
     end
   end
@@ -334,28 +334,30 @@ describe Prawn::Document do
     it 'modifies the content stream size' do
       pdf =
         described_class.new do
-          text 'Page 1'
+          text('Page 1')
           start_new_page
-          text 'Page 2'
-          go_to_page 1
-          text 'More for page 1'
+          text('Page 2')
+          go_to_page(1)
+          text('More for page 1')
         end
 
       # Indirectly verify that the actual length does not match dictionary
       # length.  If it isn't, a MalformedPDFError will be raised
-      PDF::Inspector::Page.analyze(pdf.render)
+      expect {
+        PDF::Inspector::Page.analyze(pdf.render)
+      }.to_not raise_error
     end
 
     it 'inserts pages after the current page when calling start_new_page' do
       pdf = described_class.new
       3.times do |i|
-        pdf.text "Old page #{i + 1}"
+        pdf.text("Old page #{i + 1}")
         pdf.start_new_page
       end
 
-      pdf.go_to_page 1
+      pdf.go_to_page(1)
       pdf.start_new_page
-      pdf.text 'New page 2'
+      pdf.text('New page 2')
 
       expect(pdf.page_number).to eq(2)
 
@@ -368,13 +370,13 @@ describe Prawn::Document do
     it 'restores the layout of the page' do
       doc =
         described_class.new do
-          start_new_page layout: :landscape
+          start_new_page(layout: :landscape)
         end
 
       lsize = [doc.bounds.width, doc.bounds.height]
 
       expect([doc.bounds.width, doc.bounds.height]).to eq lsize
-      doc.go_to_page 1
+      doc.go_to_page(1)
       expect([doc.bounds.width, doc.bounds.height]).to eq lsize.reverse
     end
 
@@ -384,9 +386,7 @@ describe Prawn::Document do
 
       doc.start_new_page(margin: [200, 200])
 
-      expect([doc.bounds.width, doc.bounds.height]).to eq(
-        [page1_bounds.width - 200, page1_bounds.height - 200]
-      )
+      expect([doc.bounds.width, doc.bounds.height]).to eq([page1_bounds.width - 200, page1_bounds.height - 200])
 
       doc.go_to_page(1)
 
@@ -430,9 +430,7 @@ describe Prawn::Document do
     it 'reverses coordinates for landscape' do
       pdf = described_class.new(page_size: 'A4', page_layout: :landscape)
       pages = PDF::Inspector::Page.analyze(pdf.render).pages
-      expect(pages.first[:size]).to eq(
-        PDF::Core::PageGeometry::SIZES['A4'].reverse
-      )
+      expect(pages.first[:size]).to eq(PDF::Core::PageGeometry::SIZES['A4'].reverse)
     end
 
     it 'retains page layout by default when starting a new page' do
@@ -440,9 +438,7 @@ describe Prawn::Document do
       pdf.start_new_page(trace: true)
       pages = PDF::Inspector::Page.analyze(pdf.render).pages
       pages.each do |page|
-        expect(page[:size]).to eq(
-          PDF::Core::PageGeometry::SIZES['LETTER'].reverse
-        )
+        expect(page[:size]).to eq(PDF::Core::PageGeometry::SIZES['LETTER'].reverse)
       end
     end
 
@@ -473,7 +469,7 @@ describe Prawn::Document do
   describe '#render' do
     it 'returns a 8 bit encoded string on a m17n aware VM' do
       pdf = described_class.new(page_size: 'A4', page_layout: :landscape)
-      pdf.line [100, 100], [200, 200]
+      pdf.line([100, 100], [200, 200])
       str = pdf.render
       expect(str.encoding.to_s).to eq('ASCII-8BIT')
     end
@@ -485,18 +481,17 @@ describe Prawn::Document do
       allow(pdf.renderer).to receive(:finalize_all_page_contents)
         .and_call_original
 
-      trigger = instance_double('trigger')
-      allow(trigger).to receive(:fire)
+      trigger = instance_spy(Proc, 'trigger')
+      allow(trigger).to receive(:call)
 
-      pdf.renderer.before_render { trigger.fire }
+      pdf.renderer.before_render { trigger.call }
 
       allow(pdf.renderer).to receive(:render_body).and_call_original
 
       pdf.render(StringIO.new)
 
-      expect(pdf.renderer).to have_received(:finalize_all_page_contents)
-        .ordered
-      expect(trigger).to have_received(:fire).ordered
+      expect(pdf.renderer).to have_received(:finalize_all_page_contents).ordered
+      expect(trigger).to have_received(:call).ordered
       expect(pdf.renderer).to have_received(:render_body).ordered
     end
 
@@ -527,11 +522,11 @@ describe Prawn::Document do
   describe '#go_to_page' do
     it 'has 2 pages after calling start_new_page and go_to_page' do
       pdf = described_class.new
-      pdf.text 'James'
+      pdf.text('James')
       pdf.start_new_page
-      pdf.text 'Anthony'
+      pdf.text('Anthony')
       pdf.go_to_page(1)
-      pdf.text 'Healy'
+      pdf.text('Healy')
 
       page_counter = PDF::Inspector::Page.analyze(pdf.render)
       expect(page_counter.pages.size).to eq(2)
@@ -539,25 +534,25 @@ describe Prawn::Document do
 
     it 'correctlies add text to pages' do
       pdf = described_class.new
-      pdf.text 'James'
+      pdf.text('James')
       pdf.start_new_page
-      pdf.text 'Anthony'
+      pdf.text('Anthony')
       pdf.go_to_page(1)
-      pdf.text 'Healy'
+      pdf.text('Healy')
 
       text = PDF::Inspector::Text.analyze(pdf.render)
 
       expect(text.strings.size).to eq(3)
-      expect(text.strings.include?('James')).to eq(true)
-      expect(text.strings.include?('Anthony')).to eq(true)
-      expect(text.strings.include?('Healy')).to eq(true)
+      expect(text.strings.include?('James')).to be(true)
+      expect(text.strings.include?('Anthony')).to be(true)
+      expect(text.strings.include?('Healy')).to be(true)
     end
   end
 
   describe 'content stream characteristics' do
     it 'has 1 single content stream for a single page PDF' do
       pdf = described_class.new
-      pdf.text 'James'
+      pdf.text('James')
       output = StringIO.new(pdf.render)
       hash = PDF::Reader::ObjectHash.new(output)
 
@@ -566,12 +561,11 @@ describe Prawn::Document do
       expect(streams.size).to eq(1)
     end
 
-    it 'has 1 single content stream for a single page PDF, even if go_to_page '\
-      'is used' do
+    it 'has 1 single content stream for a single page PDF, even if go_to_page is used' do
       pdf = described_class.new
-      pdf.text 'James'
+      pdf.text('James')
       pdf.go_to_page(1)
-      pdf.text 'Healy'
+      pdf.text('Healy')
       output = StringIO.new(pdf.render)
       hash = PDF::Reader::ObjectHash.new(output)
 
@@ -587,67 +581,65 @@ describe Prawn::Document do
     it "replaces the '<page>' string with the proper page number" do
       pdf.start_new_page
       allow(pdf).to receive(:text_box)
-      pdf.number_pages '<page>, test', page_filter: :all
+      pdf.number_pages('<page>, test', page_filter: :all)
       expect(pdf).to have_received(:text_box).with('1, test', height: 50)
     end
 
     it "replaces the '<total>' string with the total page count" do
       pdf.start_new_page
       allow(pdf).to receive(:text_box)
-      pdf.number_pages 'test, <total>', page_filter: :all
+      pdf.number_pages('test, <total>', page_filter: :all)
       expect(pdf).to have_received(:text_box).with('test, 1', height: 50)
     end
 
     it 'must print each page if given the :all page_filter' do
       10.times { pdf.start_new_page }
       allow(pdf).to receive(:text_box)
-      pdf.number_pages 'test', page_filter: :all
+      pdf.number_pages('test', page_filter: :all)
       expect(pdf).to have_received(:text_box).exactly(10).times
     end
 
     it 'must print each page if no :page_filter is specified' do
       10.times { pdf.start_new_page }
       allow(pdf).to receive(:text_box)
-      pdf.number_pages 'test'
+      pdf.number_pages('test')
       expect(pdf).to have_received(:text_box).exactly(10).times
     end
 
     it 'must not print the page number if given a nil filter' do
       10.times { pdf.start_new_page }
       allow(pdf).to receive(:text_box)
-      pdf.number_pages 'test', page_filter: nil
+      pdf.number_pages('test', page_filter: nil)
       expect(pdf).to_not have_received(:text_box)
     end
 
-    context 'with start_count_at option' do
-      [1, 2].each do |startat|
-        context "equal to #{startat}" do
-          it 'increments the pages' do
-            2.times { pdf.start_new_page }
-            options = { page_filter: :all, start_count_at: startat }
-            allow(pdf).to receive(:text_box)
-            pdf.number_pages '<page> <total>', options
+    [1, 2].each do |startat|
+      context "with start_count_at option equal to #{startat}" do
+        it 'increments the pages' do
+          2.times { pdf.start_new_page }
+          options = { page_filter: :all, start_count_at: startat }
+          allow(pdf).to receive(:text_box)
+          pdf.number_pages('<page> <total>', options)
 
-            expect(pdf).to have_received(:text_box)
-              .with("#{startat} 2", height: 50)
-            expect(pdf).to have_received(:text_box)
-              .with("#{startat + 1} 2", height: 50)
-          end
+          expect(pdf).to have_received(:text_box)
+            .with("#{startat} 2", height: 50)
+          expect(pdf).to have_received(:text_box)
+            .with("#{startat + 1} 2", height: 50)
         end
       end
+    end
 
-      [0, nil].each do |val|
-        context "equal to #{val}" do
-          it 'defaults to start at page 1' do
-            3.times { pdf.start_new_page }
-            options = { page_filter: :all, start_count_at: val }
-            allow(pdf).to receive(:text_box)
-            pdf.number_pages '<page> <total>', options
+    [0, nil].each do |val|
+      context "with start_count_at option equal to #{val}" do
+        it 'defaults to start at page 1' do
+          3.times { pdf.start_new_page }
+          options = { page_filter: :all, start_count_at: val }
+          allow(pdf).to receive(:text_box)
+          pdf.number_pages('<page> <total>', options)
 
-            expect(pdf).to have_received(:text_box).with('1 3', height: 50)
-            expect(pdf).to have_received(:text_box).with('2 3', height: 50)
-            expect(pdf).to have_received(:text_box).with('3 3', height: 50)
-          end
+          expect(pdf).to have_received(:text_box).with('1 3', height: 50)
+          expect(pdf).to have_received(:text_box).with('2 3', height: 50)
+          expect(pdf).to have_received(:text_box).with('3 3', height: 50)
         end
       end
     end
@@ -656,7 +648,7 @@ describe Prawn::Document do
       it 'allows the total pages count to be overridden' do
         2.times { pdf.start_new_page }
         allow(pdf).to receive(:text_box)
-        pdf.number_pages '<page> <total>', page_filter: :all, total_pages: 10
+        pdf.number_pages('<page> <total>', page_filter: :all, total_pages: 10)
 
         expect(pdf).to have_received(:text_box).with('1 10', height: 50)
         expect(pdf).to have_received(:text_box).with('2 10', height: 50)
@@ -668,7 +660,7 @@ describe Prawn::Document do
         it 'increments the pages' do
           3.times { pdf.start_new_page }
           allow(pdf).to receive(:text_box)
-          pdf.number_pages '<page> <total>', page_filter: :odd
+          pdf.number_pages('<page> <total>', page_filter: :odd)
 
           expect(pdf).to have_received(:text_box).with('1 3', height: 50)
           expect(pdf).to have_received(:text_box).with('3 3', height: 50)
@@ -680,7 +672,7 @@ describe Prawn::Document do
         it 'does not print any page numbers' do
           3.times { pdf.start_new_page }
           allow(pdf).to receive(:text_box)
-          pdf.number_pages '<page> <total>', page_filter: nil
+          pdf.number_pages('<page> <total>', page_filter: nil)
 
           expect(pdf).to_not have_received(:text_box)
         end
@@ -692,9 +684,7 @@ describe Prawn::Document do
         it 'increments the pages' do
           3.times { pdf.start_new_page }
           allow(pdf).to receive(:text_box)
-          pdf.number_pages '<page> <total>',
-            page_filter: :odd,
-            start_count_at: 5
+          pdf.number_pages('<page> <total>', page_filter: :odd, start_count_at: 5)
 
           expect(pdf).to_not have_received(:text_box).with('1 3', height: 50)
           # page 1
@@ -713,10 +703,10 @@ describe Prawn::Document do
           6.times { pdf.start_new_page }
           options = {
             page_filter: ->(p) { p != 2 && p != 5 },
-            start_count_at: 4
+            start_count_at: 4,
           }
           allow(pdf).to receive(:text_box)
-          pdf.number_pages '<page> <total>', options
+          pdf.number_pages('<page> <total>', options)
 
           # page 1
           expect(pdf).to have_received(:text_box).with('4 6', height: 50)
@@ -746,19 +736,19 @@ describe Prawn::Document do
 
       it 'with 10 height' do
         allow(pdf).to receive(:text_box)
-        pdf.number_pages '<page> <total>', height: 10
+        pdf.number_pages('<page> <total>', height: 10)
         expect(pdf).to have_received(:text_box).with('1 1', height: 10)
       end
 
       it 'with nil height' do
         allow(pdf).to receive(:text_box)
-        pdf.number_pages '<page> <total>', height: nil
+        pdf.number_pages('<page> <total>', height: nil)
         expect(pdf).to have_received(:text_box).with('1 1', height: nil)
       end
 
       it 'with no height' do
         allow(pdf).to receive(:text_box)
-        pdf.number_pages '<page> <total>'
+        pdf.number_pages('<page> <total>')
         expect(pdf).to have_received(:text_box).with('1 1', height: 50)
       end
     end
@@ -777,12 +767,12 @@ describe Prawn::Document do
 
     it 'must provide an :all filter' do
       expect((1..pdf.page_count).all? { |i| pdf.page_match?(:all, i) })
-        .to eq true
+        .to be true
     end
 
     it 'must provide an :odd filter' do
       odd, even = (1..pdf.page_count).partition(&:odd?)
-      expect(odd.all? { |i| pdf.page_match?(:odd, i) }).to eq true
+      expect(odd.all? { |i| pdf.page_match?(:odd, i) }).to be true
       expect(even).to_not(be_any { |i| pdf.page_match?(:odd, i) })
     end
 
